Class: Cellect::Client::NodeSet
- Inherits:
-
Object
- Object
- Cellect::Client::NodeSet
- Defined in:
- lib/cellect/client/node_set.rb
Instance Attribute Summary collapse
-
#nodes ⇒ Object
Returns the value of attribute nodes.
Instance Method Summary collapse
-
#initialize ⇒ NodeSet
constructor
Gets the current list of nodes and listens to changes.
Constructor Details
#initialize ⇒ NodeSet
Gets the current list of nodes and listens to changes
7 8 9 10 11 12 |
# File 'lib/cellect/client/node_set.rb', line 7 def initialize self.nodes = Attention.instances Attention.on_change do |change, instances| self.nodes = instances end end |
Instance Attribute Details
#nodes ⇒ Object
Returns the value of attribute nodes.
4 5 6 |
# File 'lib/cellect/client/node_set.rb', line 4 def nodes @nodes end |